@@ -36,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.2.5"
+		Version = "v10.2.7"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -119,7 +119,7 @@ func Run() (err error) {
 		&cli.StringFlag{Name: "pass", Value: models.DEFAULT_PASSPHRASE, Usage: "password for the relay", EnvVars: []string{"CROC_PASS"}},
 		&cli.StringFlag{Name: "socks5", Value: "", Usage: "add a socks5 proxy", EnvVars: []string{"SOCKS5_PROXY"}},
 		&cli.StringFlag{Name: "connect", Value: "", Usage: "add a http proxy", EnvVars: []string{"HTTP_PROXY"}},
-		&cli.StringFlag{Name: "throttleUpload", Value: "", Usage: "Throttle the upload speed e.g. 500k"},
+		&cli.StringFlag{Name: "throttleUpload", Value: "", Usage: "throttle the upload speed e.g. 500k"},
 	}
 	app.EnableBashCompletion = true
 	app.HideHelp = false
@@ -329,9 +329,6 @@ func send(c *cli.Context) (err error) {
 			return
 		}
 		// update anything that isn't explicitly set
-		if !c.IsSet("relay") && rememberedOptions.RelayAddress != "" {
-			crocOptions.RelayAddress = rememberedOptions.RelayAddress
-		}
 		if !c.IsSet("no-local") {
 			crocOptions.DisableLocal = rememberedOptions.DisableLocal
 		}
@@ -344,9 +341,6 @@ func send(c *cli.Context) (err error) {
 		if !c.IsSet("pass") && rememberedOptions.RelayPassword != "" {
 			crocOptions.RelayPassword = rememberedOptions.RelayPassword
 		}
-		if !c.IsSet("relay6") && rememberedOptions.RelayAddress6 != "" {
-			crocOptions.RelayAddress6 = rememberedOptions.RelayAddress6
-		}
 		if !c.IsSet("overwrite") {
 			crocOptions.Overwrite = rememberedOptions.Overwrite
 		}
@@ -478,9 +472,7 @@ Or you can go back to the classic croc behavior by enabling classic mode:
 
 	// save the config
 	saveConfig(c, crocOptions)
-
 	err = cr.Send(minimalFileInfos, emptyFoldersToTransfer, totalNumberFolders)
-
 	return
 }
 
@@ -628,9 +620,6 @@ func receive(c *cli.Context) (err error) {
 			return
 		}
 		// update anything that isn't explicitly Globally set
-		if !c.IsSet("relay") && rememberedOptions.RelayAddress != "" {
-			crocOptions.RelayAddress = rememberedOptions.RelayAddress
-		}
 		if !c.IsSet("yes") {
 			crocOptions.NoPrompt = rememberedOptions.NoPrompt
 		}
@@ -640,9 +629,6 @@ func receive(c *cli.Context) (err error) {
 		if !c.IsSet("pass") && rememberedOptions.RelayPassword != "" {
 			crocOptions.RelayPassword = rememberedOptions.RelayPassword
 		}
-		if !c.IsSet("relay6") && rememberedOptions.RelayAddress6 != "" {
-			crocOptions.RelayAddress6 = rememberedOptions.RelayAddress6
-		}
 		if !c.IsSet("overwrite") {
 			crocOptions.Overwrite = rememberedOptions.Overwrite
 		}
